# Copyright 2016 Red Hat, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.
#
# == Class: swift::storage::loopbacks
#
# Class wrapper for the benefit of Hiera users
#
# === Parameters:
#
# [*args*] A Swift 'loopback' config hash
#   Optional. Defaults to a empty hash
#
# [*defaults*] A config hash
#   Optional. Defaults to a empty hash
#
class swift::storage::loopbacks($args = {}, $defaults = {}) {
  create_resources(swift::storage::loopback, $args, $defaults)
}
